@@ -17,6 +17,14 @@ class VelocityKPI(EmbeddedDocument):
     space_percent = FloatField()
 
 
+class IssuesTotal(EmbeddedDocument):
+    """The infrastructure KPI total and sub-totals."""
+    code_warnings = IntField(default=0)
+    code_errors = IntField(default=0)
+    devops_warnings = IntField(default=0)
+    devops_errors = IntField(default=0)
+    
+
 class RepoEvents(Document):
     """The repository events collection model.
 
@@ -50,6 +58,7 @@ class RepoEvents(Document):
     commit_files = ListField()
     
     velocity_kpi = EmbeddedDocumentField(VelocityKPI)
+    issues_total = EmbeddedDocumentField(IssuesTotal)
 
     # Category and Tokens
     repo_type = StringField()
@@ -69,10 +78,17 @@ class LinterScanEvent(EmbeddedDocument):
         warnings_total (IntField): Total number of warnings.
         linter_output (StringField): Full output from the linter.
     """
+    
+    file_type = StringField()
     linter_name = StringField()
     file_path = StringField()
-    errors_total = IntField()
-    warnings_total = IntField()
+
+    devops_warnings = IntField()
+    devops_errors = IntField()
+
+    code_warnings = IntField()
+    code_errors = IntField()
+
     linter_output = StringField()
 
 
@@ -92,18 +108,18 @@ class CicdKPI(EmbeddedDocument):
     cicd_total = FloatField(default=0.0)
     pipeline = FloatField(default=0.0)
     testing = FloatField(default=0.0)
-    static_analyis = FloatField(default=0.0)
+    static_analysis = FloatField(default=0.0)
     deploy = FloatField(default=0.0)
 
 
 class SecurityKPI(EmbeddedDocument):
     """The risk KPI total and sub-totals."""
 
-    secutiry_total = FloatField(default=0.0)
+    security_total = FloatField(default=0.0)
+    least_privledge = FloatField(default=0.0)
     secrets = FloatField(default=0.0)
     auth = FloatField(default=0.0)
     keys = FloatField(default=0.0)
-    compliance = FloatField(default=0.0)
 
 
 class InfrastructureKPI(EmbeddedDocument):
@@ -116,14 +132,6 @@ class InfrastructureKPI(EmbeddedDocument):
     tags = FloatField(default=0.0)
 
 
-class IssuesTotal(EmbeddedDocument):
-    """The infrastructure KPI total and sub-totals."""
-    code_warnings = FloatField(default=0.0)
-    code_errors = FloatField(default=0.0)
-    devops_warnings = FloatField(default=0.0)
-    devops_errors = FloatField(default=0.0)
-
-
 class DevelopmentKPI(EmbeddedDocument):
     """The investment KPI total and sub-totals."""
 
